@@ -5,11 +5,11 @@ from typing import List, Optional, Union
 import pandas as pd
 from aqueduct.artifacts.base_artifact import BaseArtifact
 from aqueduct.artifacts.preview import preview_artifact
-from aqueduct.artifacts.save import save_artifact
 from aqueduct.artifacts.table_artifact import TableArtifact
 from aqueduct.constants.enums import ArtifactType, ExecutionMode, LoadUpdateMode, ServiceType
 from aqueduct.error import InvalidUserActionException, InvalidUserArgumentException
-from aqueduct.logger import logger
+from aqueduct.integrations.naming import _resolve_op_and_artifact_name_for_extract
+from aqueduct.integrations.save import _save_artifact
 from aqueduct.models.artifact import ArtifactMetadata
 from aqueduct.models.dag import DAG
 from aqueduct.models.integration import Integration, IntegrationInfo
@@ -19,20 +19,20 @@ from aqueduct.models.operators import (
     OperatorSpec,
     RelationalDBExtractParams,
     RelationalDBLoadParams,
-    SaveConfig,
 )
 from aqueduct.utils.dag_deltas import AddOrReplaceOperatorDelta, apply_deltas_to_dag
-from aqueduct.utils.utils import artifact_name_from_op_name, generate_uuid
+from aqueduct.utils.utils import generate_uuid
 
 from aqueduct import globals
 
 LIST_TABLES_QUERY_PG = "SELECT tablename, tableowner FROM pg_catalog.pg_tables WHERE schemaname != 'pg_catalog' AND schemaname != 'information_schema';"
 LIST_TABLES_QUERY_SNOWFLAKE = "SELECT table_name AS \"tablename\", table_owner AS \"tableowner\" FROM information_schema.tables WHERE table_schema != 'INFORMATION_SCHEMA' AND table_type = 'BASE TABLE';"
 LIST_TABLES_QUERY_MYSQL = "SELECT table_name FROM INFORMATION_SCHEMA.TABLES WHERE table_type = 'BASE TABLE' AND table_schema NOT IN ('mysql', 'sys', 'performance_schema');"
+LIST_TABLES_QUERY_MARIADB = "SELECT table_name AS \"tablename\" FROM INFORMATION_SCHEMA.TABLES WHERE table_type = 'BASE TABLE' AND table_schema NOT IN ('mysql', 'sys', 'performance_schema');"
+
 LIST_TABLES_QUERY_SQLSERVER = (
     "SELECT table_name FROM INFORMATION_SCHEMA.TABLES WHERE table_type = 'BASE TABLE';"
 )
-LIST_TABLES_QUERY_BIGQUERY = "SELECT schema_name FROM information_schema.schemata;"
 GET_TABLE_QUERY = "select * from %s"
 LIST_TABLES_QUERY_SQLITE = "SELECT name AS tablename FROM sqlite_master WHERE type='table';"
 LIST_TABLES_QUERY_ATHENA = "AQUEDUCT_ATHENA_LIST_TABLE"
@@ -45,6 +45,7 @@ TAG_PATTERN = r"{{\s*[\w-]+\s*}}"
 # The TAG for 'previous table' when the user specifies a chained query.
 PREV_TABLE_TAG = "$"
 
+
 # A dictionary of built-in tags to their replacement string functions.
 def replace_today() -> str:
     return "'" + date.today().strftime("%Y-%m-%d") + "'"
@@ -103,6 +104,12 @@ class RelationalDBIntegration(Integration):
         Returns:
             pd.DataFrame of available tables.
         """
+        if self.type() in [ServiceType.BIGQUERY]:
+            # Use the list integration objects endpoint instead of
+            # providing a hardcoded SQL query to execute
+            tables = globals.__GLOBAL_API_CLIENT__.list_tables(str(self.id()))
+            return pd.DataFrame(tables, columns=["tablename"])
+
         if self.type() in [
             ServiceType.POSTGRES,
             ServiceType.AQUEDUCTDEMO,
@@ -111,12 +118,12 @@ class RelationalDBIntegration(Integration):
             list_tables_query = LIST_TABLES_QUERY_PG
         elif self.type() == ServiceType.SNOWFLAKE:
             list_tables_query = LIST_TABLES_QUERY_SNOWFLAKE
-        elif self.type() in [ServiceType.MYSQL, ServiceType.MARIADB]:
+        elif self.type() == ServiceType.MYSQL:
             list_tables_query = LIST_TABLES_QUERY_MYSQL
+        elif self.type() == ServiceType.MARIADB:
+            list_tables_query = LIST_TABLES_QUERY_MARIADB
         elif self.type() == ServiceType.SQLSERVER:
             list_tables_query = LIST_TABLES_QUERY_SQLSERVER
-        elif self.type() == ServiceType.BIGQUERY:
-            list_tables_query = LIST_TABLES_QUERY_BIGQUERY
         elif self.type() == ServiceType.SQLITE:
             list_tables_query = LIST_TABLES_QUERY_SQLITE
         elif self.type() == ServiceType.ATHENA:
@@ -143,6 +150,7 @@ class RelationalDBIntegration(Integration):
         self,
         query: Union[str, List[str], RelationalDBExtractParams],
         name: Optional[str] = None,
+        output: Optional[str] = None,
         description: str = "",
         lazy: bool = False,
     ) -> TableArtifact:
@@ -155,6 +163,8 @@ class RelationalDBIntegration(Integration):
                 in a chain and return the result of the final query.
             name:
                 Name of the query.
+            output:
+                Name to assign the output artifact. If not set, the default naming scheme will be used.
             description:
                 Description of the query.
             lazy:
@@ -165,17 +175,15 @@ class RelationalDBIntegration(Integration):
         """
         if globals.__GLOBAL_CONFIG__.lazy:
             lazy = True
-        execution_mode = ExecutionMode.EAGER if not lazy else ExecutionMode.LAZY
 
-        integration_info = self._metadata
+        execution_mode = ExecutionMode.LAZY if lazy else ExecutionMode.EAGER
 
-        # The sql operator name defaults to "[integration name] query 1". If another
-        # sql operator already exists with that name, we'll continue bumping the suffix
-        # until the sql operator is unique. If an explicit name is provided, we will
-        # overwrite the existing one.
-        sql_op_name = name
-        if sql_op_name is None:
-            sql_op_name = self._dag.get_unclaimed_op_name(prefix="%s query" % self.name())
+        op_name, artifact_name = _resolve_op_and_artifact_name_for_extract(
+            dag=self._dag,
+            op_name=name,
+            default_op_name="%s query" % self.name(),
+            artifact_name=output,
+        )
 
         extract_params = query
         if isinstance(extract_params, str):
@@ -235,7 +243,7 @@ class RelationalDBIntegration(Integration):
                 AddOrReplaceOperatorDelta(
                     op=Operator(
                         id=sql_operator_id,
-                        name=sql_op_name,
+                        name=op_name,
                         description=description,
                         spec=OperatorSpec(
                             extract=ExtractSpec(
@@ -250,7 +258,7 @@ class RelationalDBIntegration(Integration):
                     output_artifacts=[
                         ArtifactMetadata(
                             id=sql_output_artifact_id,
-                            name=artifact_name_from_op_name(sql_op_name),
+                            name=artifact_name,
                             type=ArtifactType.TABLE,
                         ),
                     ],
@@ -267,33 +275,6 @@ class RelationalDBIntegration(Integration):
             # We are in lazy mode.
             return TableArtifact(self._dag, sql_output_artifact_id)
 
-    def config(self, table: str, update_mode: LoadUpdateMode) -> SaveConfig:
-        """TODO(ENG-2035): Deprecated and will be removed.
-        Configuration for saving to RelationalDB Integration.
-
-        Arguments:
-            table:
-                Table to save to.
-            update_mode:
-                The update mode to use when saving the artifact as a relational table.
-                Possible values are: APPEND, REPLACE, or FAIL.
-        Returns:
-            SaveConfig object to use in TableArtifact.save()
-        """
-        logger().warning(
-            "`integration.config()` is deprecated. Please use `integration.save()` directly instead."
-        )
-
-        if self.type() == ServiceType.ATHENA:
-            raise InvalidUserActionException(
-                "Save operation is not supported for integration type %s." % self.type().value
-            )
-
-        return SaveConfig(
-            integration_info=self._metadata,
-            parameters=RelationalDBLoadParams(table=table, update_mode=update_mode),
-        )
-
     def save(self, artifact: BaseArtifact, table_name: str, update_mode: LoadUpdateMode) -> None:
         """Registers a save operator of the given artifact, to be executed when it's computed in a published flow.
 
@@ -306,9 +287,18 @@ class RelationalDBIntegration(Integration):
                 Defines the semantics of the save if a table already exists.
                 Options are "replace", "append" (row-wise), or "fail" (if table already exists).
         """
-        save_artifact(
+        if self.type() == ServiceType.ATHENA:
+            raise InvalidUserActionException(
+                "Save operation not supported for %s." % self.type().value
+            )
+        # Non-tabular data cannot be saved into relational data stores.
+        if artifact.type() not in [ArtifactType.UNTYPED, ArtifactType.TABLE]:
+            raise InvalidUserActionException(
+                "Unable to save non-relational data into relational data store `%s`." % self.name()
+            )
+
+        _save_artifact(
             artifact.id(),
-            artifact.type(),
             self._dag,
             self._metadata,
             save_params=RelationalDBLoadParams(table=table_name, update_mode=update_mode),
