@@ -3,14 +3,14 @@ import sys
 from io import StringIO
 from unittest.mock import MagicMock
 
+from aqueduct.artifacts.numeric_artifact import NumericArtifact
+from aqueduct.constants.enums import ArtifactType, SerializationType
 from aqueduct.decorator import check, metric
-from aqueduct.enums import ExecutionStatus
-from aqueduct.metric_artifact import MetricArtifact
-from aqueduct.responses import ArtifactResult, MetricArtifactResult, OperatorResult, PreviewResponse
-from aqueduct.tests.utils import default_table_artifact
-from aqueduct.utils import delete_zip_folder_and_file, generate_uuid
+from aqueduct.tests.utils import construct_mocked_preview, default_table_artifact
+from aqueduct.utils.function_packaging import delete_zip_folder_and_file
+from aqueduct.utils.utils import generate_uuid
 
-from aqueduct import api_client
+from aqueduct import globals
 
 metric_op_name = "metric_fn"
 description = f"{metric_op_name} description"
@@ -38,44 +38,34 @@ def test_metric():
     )
     dag = metric_input._dag
 
+    globals.__GLOBAL_API_CLIENT__.preview = MagicMock(
+        side_effect=construct_mocked_preview(
+            metric_artifact_name,
+            ArtifactType.NUMERIC,
+            SerializationType.JSON,
+            output,  # dummy metric value
+        )
+    )
+
     try:
-        metric_output: MetricArtifact = metric_fn(metric_input)
+        metric_output: NumericArtifact = metric_fn(metric_input)
     finally:
         delete_zip_folder_and_file(zip_folder)
 
-    status = ExecutionStatus.SUCCEEDED
-    operator_results = {
-        op_id: OperatorResult(),
-    }
-    artifact_results = {
-        metric_output.id(): ArtifactResult(metric=MetricArtifactResult(val=output)),
-    }
-    preview_output = PreviewResponse(
-        status=status,
-        operator_results=operator_results,
-        artifact_results=artifact_results,
-    )
-    api_client.__GLOBAL_API_CLIENT__.preview = MagicMock(return_value=preview_output)
-
     metric_val = metric_output.get()
 
-    api_client.__GLOBAL_API_CLIENT__.preview.assert_called_with(dag=dag)
     assert len(dag.operators) == len(dag.artifacts)
     assert len(dag.operators) == 2
 
     artifact_check = {
-        artifact_name: {
-            "float": None,
-            "table": {},
-        },
-        metric_artifact_name: {"float": {}, "table": None},
+        artifact_name: ArtifactType.TABLE,
+        metric_artifact_name: ArtifactType.NUMERIC,
     }
 
     for artifact in dag.artifacts:
         artifact = dag.artifacts[artifact]
         assert artifact.name in artifact_check.keys()
-        assert artifact.spec.float == artifact_check[artifact.name]["float"]
-        assert artifact.spec.table == artifact_check[artifact.name]["table"]
+        assert artifact.type == artifact_check[artifact.name]
         if artifact.name == metric_artifact_name:
             metric_artifact_id = artifact.id
 
@@ -111,7 +101,7 @@ def test_metrics_and_checks_on_table_describe():
     metric_input = default_table_artifact()
 
     try:
-        metric_output: MetricArtifact = metric_fn(metric_input)
+        metric_output: NumericArtifact = metric_fn(metric_input)
     finally:
         delete_zip_folder_and_file(zip_folder)
 
@@ -122,6 +112,18 @@ def test_metrics_and_checks_on_table_describe():
         return metric_output > 0
 
     check_name = "check_fn"
+    check_artifact_name = f"{check_name} artifact"
+    check_output = True
+
+    globals.__GLOBAL_API_CLIENT__.preview = MagicMock(
+        side_effect=construct_mocked_preview(
+            check_artifact_name,
+            ArtifactType.BOOL,
+            SerializationType.JSON,
+            check_output,  # dummy check value
+        )
+    )
+
     check_fn(metric_output)
 
     redirect_stdout = StringIO()
